<?php
/*
Plugin Name: WP e-Commerce Livraison France
Plugin URI: http://wpcb.fr/plugin-livraison-france
Description: Livraison depuis la France vers la France et l'étranger (Plugin requis : WP e-Commerce)
Version: 1.0.2
Author: 6WWW
Author URI: http://6www.net
License: GPL2
*/

/*  Copyright 2011  SARL 6WWW

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

class postefrancaise {
	var $internal_name, $name;
	var $services = array();
	var $settings;
	var $base_country;
	var $base_zipcode;
	
	/**
	 * Constructor
	 */
	function postefrancaise () {
		$this->internal_name = "postefrancaise";
		$this->name = 'Poste Française';
		$this->is_external = true;
		$this->requires_weight = true;
		$this->needs_zipcode = true;
		$this->debug = false; // change to true to log (to the PHP error log) the API URLs and responses for each active service
		
		// Initialise the list of available postage services
		$this->services['COLISSIMO'] = __('Colissimo', 'wpsc');
		$this->services['CHRONOPOST'] = __('Chronopost', 'wpsc');
		$this->services['ENLEVEMENT'] = __('Enlèvement sur place', 'wpsc');
		
		// Attempt to load the existing settings
		$this->settings = get_option("wpsc_postefrancaise_settings");
		$this->address = get_option("wpsc_postefrancaise_address");
		
		$this->base_country = get_option('base_country');
		$this->base_zipcode = get_option('base_zipcode');
		
		if (!$this->settings) {
			// Initialise the settings
			$this->settings = array();
			foreach ($this->services as $code => $value) {
				$this->settings['services'][$code] = true;
			}
			update_option('wpsc_postefrancaise_settings', $this->settings);
		}
		
		return true;
	}
	
	function getId() {
	}
	
	function setId($id) {
	}
	
	function getName() {
		return $this->name;
	}
	
	function getInternalName() {
		return $this->internal_name;
	}
	
	function getForm() {
		$output = '';
		if ($this->base_country != 'FR') {
			return __('Ne fonctionne que pour un commerçant basé en France.', 'wpsc');
		}
		
		// ZIP doit être saisi
		if (strlen($this->base_zipcode) != 5) {
			return __('Entrer votre code postal pus haut sur cette page.', 'wpsc');
		}
		
				$output .= "<tr><td><p>Adresse physique :</p></td></tr><tr><td><input type='text' name='{$this->address}' value='";
		$output.=get_option('wpsc_postefrancaise_address', $this->address);
		$output.="'></td></tr>";
		$output .= "<tr><td>" . __('Choisissez les services que vous voulez proposer:', 'wpsc') . "</td></tr>\n\r";
		$output .= "<tr><td>\n\r";
		foreach ($this->services as $code => $value) {
			$checked = $this->settings['services'][$code] ? "checked='checked'" : '';
			$output .= "		<label style=\"margin-left: 50px;\"><input type='checkbox' {$checked} name='wpsc_postefrancaise_settings[services][{$code}]'/>{$this->services[$code]}</label><br />\n\r";
		}
		$output .= "<input type='hidden' name='{$this->internal_name}_updateoptions' value='true'>";
		$output .= "</td></tr>";
		$output .= "<tr><td><h4>" . __('Notes:', 'wpsc') . "</h4>";
		$output .= '1. L\'acheteur aura le choix de la méthode de livraison au moment de régler son panier.<br />';
		$output .= '2. Le poids de chaque produit doit être renseigné.<br />';
		$output .= '3. Les dimensions de chaque produit doivent être renseignées (optionel)<br />';
		$output .= "</tr></td>";
		return $output;
	}
	
	function submit_form() {
		$this->settings['services'] = array();

		// Only continue if this module's options were updated
		if ( !isset($_POST["{$this->internal_name}_updateoptions"]) || !$_POST["{$this->internal_name}_updateoptions"] ) return;
		
		if (isset($_POST['wpsc_postefrancaise_settings'])) {
			if (isset($_POST['wpsc_postefrancaise_settings']['services'])) {
				foreach ($this->services as $code => $name) {
					$this->settings['services'][$code] = isset($_POST['wpsc_postefrancaise_settings']['services'][$code]) ? true : false;
				}
			}
		}

		update_option('wpsc_postefrancaise_settings', $this->settings);
		update_option('wpsc_postefrancaise_address', $this->address);
		return true;
	}
	
	function getQuote() {
		global $wpdb, $wpsc_cart;
		if ($this->base_country != 'FR' || strlen($this->base_zipcode) != 5 || !count($wpsc_cart->cart_items)) return;
		$dest = $_SESSION['wpsc_delivery_country'];
		$destzipcode = '';
		if(isset($_POST['zipcode'])) {
			$destzipcode = $_POST['zipcode'];      
			$_SESSION['wpsc_zipcode'] = $_POST['zipcode'];
		} else if(isset($_SESSION['wpsc_zipcode'])) {$destzipcode = $_SESSION['wpsc_zipcode'];}
		if ($dest == 'FR' && strlen($destzipcode) != 5) {return array();}

		/*
		3 possible scenarios:

		1.
		Cart consists of only item(s) that have "disregard shipping" ticked.

		In this case, WPEC doesn't mention shipping at all during checkout, and this shipping module probably won't be executed at all.

		Just in case it does get queried, we should still query the Australia Post API for valid shipping estimates,
		and then override the quoted price(s) to $0.00 so the customer is able to get free shipping.


		2.
		Cart consists of only item(s) where "disregard shipping" isn't ticked (ie. all item(s) attract shipping charges).

		In this case, we should query the Australia Post API as per normal.


		3.
		Cart consists of one or more "disregard shipping" product(s), and one or more other products that attract shipping charges.

		In this case, we should query the Aus Post API, only taking into account the product(s) that attract shipping charges.
		Products with "disregard shipping" ticked shouldn't have their weight or dimensions included in the quote.
		*/
		

		// Weight is in grams
		$weight = wpsc_convert_weight($wpsc_cart->calculate_total_weight(true), 'pound', 'gram');
		// Calculate the total cart dimensions by adding the volume of each product then calculating the cubed root
		$volume = 0;
		// Total number of item(s) in the cart
		$numItems = count($wpsc_cart->cart_items);

		if ($numItems == 0) {
		    // The customer's cart is empty. This probably shouldn't occur, but just in case!
		    return array();
		}

		// Total number of item(s) that don't attract shipping charges.
		$numItemsWithDisregardShippingTicked = 0;

		foreach($wpsc_cart->cart_items as $cart_item) {
			
			if ( !$cart_item->uses_shipping ) {
			    // The "Disregard Shipping for this product" option is ticked for this item.
			    // Don't include it in the shipping quote.
			    $numItemsWithDisregardShippingTicked++;
			    continue;
			}

			// If we are here then this item attracts shipping charges.
			
			$meta = get_product_meta($cart_item->product_id,'product_metadata',true);
			$meta = $meta['dimensions'];

			if ($meta && is_array($meta)) {
				$productVolume = 1;
				foreach (array('width','height','length') as $dimension) {
					
					switch ($meta["{$dimension}_unit"]) {
						// we need the units in mm
						case 'cm':
							// convert from cm to mm
							$productVolume = $productVolume * (floatval($meta[$dimension]) * 10);
							break;
						case 'meter':
							// convert from m to mm
							$productVolume = $productVolume * (floatval($meta[$dimension]) * 1000);
							break;
						case 'in':
							// convert from in to mm
							$productVolume = $productVolume * (floatval($meta[$dimension]) * 25.4);
							break;
					}
				}
				$volume += floatval($productVolume);
			}
		}
		
		// Calculate the cubic root of the total volume, rounding up
		$cuberoot = ceil(pow($volume, 1 / 3));
		
		// Use default dimensions of 100mm if the volume is zero
		$height=100;
		$width=100;
		$length=100;
		
		if ($cuberoot > 0) {
		    $height = $width = $length = $cuberoot;
		}

		if ($length < 100) $length = 100;
		if ($width < 100) $width = 100;

		$shippingPriceNeedsToBeZero = false;
		
		if ($numItemsWithDisregardShippingTicked == $numItems) {
		    // The cart consists of entirely "disregard shipping" products, so the shipping quote(s) should be $0.00
		    // Set the weight to 1 gram so that we can obtain valid Australia Post quotes (which we will then ignore the quoted price of)
		    $weight = 1;
		    $shippingPriceNeedsToBeZero = true;
		}
		
		$params = array(
		    'Pickup_Postcode' => $this->base_zipcode
		    , 'Destination_Postcode' => $destzipcode
		    , 'Quantity' => 1
		    , 'Weight' => $weight
		    , 'Height' => $height
		    , 'Width' => $width
		    , 'Length' => $length
		    , 'Country' => $dest
		);

		// COLISSIMO :
		$service_postefrancaise='COLISSIMO';
		// Utilisation de l'api "home-made" (uniquement a destination de france métropolitaine)
		if ($params['Country']=='FR'){
			$methods[$service_postefrancaise]['name']='Colissimo France Métropolitaine';
			$methods[$service_postefrancaise]['days']=4; // Temps de livraison standard France métropolitaine // todo : faire une option
		
			$curl_connection = curl_init('http://www.laposte.fr/Particulier/Utiliser-nos-outils-pratiques/Outils-et-documents/Calculez-le-tarif-de-vos-envois');
			curl_setopt($curl_connection, CURLOPT_CONNECTTIMEOUT, 30);
			curl_setopt($curl_connection, CURLOPT_USERAGENT,"Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)");
			curl_setopt($curl_connection, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curl_connection, CURLOPT_SSL_VERIFYPEER, false);
			curl_setopt($curl_connection, CURLOPT_FOLLOWLOCATION, 1);
			$post_data['type'] = 'colis'; //colis ou courrier
			$post_data['from'] = '0'; // Depuis la france
			$post_data['recoON'] = 'non';
			$post_data['gr'] = $params['Weight']; // En grammes
			$post_data['destination'] = 'France Métropolitaine';
			$post_data['nature'] = 'colissimo'; //colissimo ou chronopost
			
			foreach ( $post_data as $key => $value) {$post_items[] = $key . '=' . $value;}
			$post_string = implode ('&', $post_items); 
			curl_setopt($curl_connection, CURLOPT_POSTFIELDS, $post_string); 
			$result = curl_exec($curl_connection);
			$TotalStr='Total&nbsp;: ';
			$posTotalStr = strpos($result,$TotalStr);
			$EuroStr=' &euro;</strong></span>';
			$posEuroStr = strpos($result,$EuroStr);
			$quote=str_replace(',','.',substr  ( $result,$posTotalStr+strlen($TotalStr),$posEuroStr-($posTotalStr+strlen($TotalStr))));
			if ($quote){$methods[$service_postefrancaise]['charge']=$quote;$methods[$service_postefrancaise]['err_msg']='OK';}
			else { // l'API n'a pas fonctionné
				//Table tarifaire Colissimo France Métropolitaine
				if($params['Weight']>=0 && $params['Weight']<=500){$methods[$service_postefrancaise]['charge']=5.60;$methods[$service_postefrancaise]['err_msg']='OK';}
				elseif ($params['Weight']>500 && $params['Weight']<=1000){$methods[$service_postefrancaise]['charge']=6.95;$methods[$service_postefrancaise]['err_msg']='OK';}
				elseif ($params['Weight']>1000 && $params['Weight']<=2000){$methods[$service_postefrancaise]['charge']=7.95;$methods[$service_postefrancaise]['err_msg']='OK';}
				elseif ($params['Weight']>2000 && $params['Weight']<=3000){$methods[$service_postefrancaise]['charge']=8.95;$methods[$service_postefrancaise]['err_msg']='OK';}
				elseif ($params['Weight']>3000 && $params['Weight']<=5000){$methods[$service_postefrancaise]['charge']=10.95;$methods[$service_postefrancaise]['err_msg']='OK';}
				elseif ($params['Weight']>5000 && $params['Weight']<=7000){$methods[$service_postefrancaise]['charge']=12.95;$methods[$service_postefrancaise]['err_msg']='OK';}
				elseif ($params['Weight']>7000 && $params['Weight']<=10000){$methods[$service_postefrancaise]['charge']=15.95;$methods[$service_postefrancaise]['err_msg']='OK';}
				elseif ($params['Weight']>10000 && $params['Weight']<=15000){$methods[$service_postefrancaise]['charge']=18.20;$methods[$service_postefrancaise]['err_msg']='OK';}
				elseif ($params['Weight']>15000 && $params['Weight']<=30000){$methods[$service_postefrancaise]['charge']=24.90;$methods[$service_postefrancaise]['err_msg']='OK';}
				else {$methods[$service_postefrancaise]['err_msg']='Poids non trouvé';}
			}
		//echo "<hr/>Toute la page :<br/>";
		// Echo all the page :
		//echo $result.'<br/>';
		//show information regarding the request
		//print_r(curl_getinfo($curl_connection));
		//echo curl_errno($curl_connection) . '-' . curl_error($curl_connection);
		}
		elseif ( $params['Country']=='GP' || $params['Country']=='MQ' || $params['Country']=='GY' || $params['Country']=='RE' || $params['Country']=='YT' || $params['Country']=='PM' ){
			$methods[$service_postefrancaise]['name']='Colissimo Outre-Mer Zone 1';
			$methods[$service_postefrancaise]['days']=''; // Temps de livraison standard Zone OM1 // todo : faire une option
		// Zone OM 1
			if($params['Weight']>=0 && $params['Weight']<=500){$methods[$service_postefrancaise]['charge']=8.45;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>500 && $params['Weight']<=1000){$methods[$service_postefrancaise]['charge']=12.70;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>1000 && $params['Weight']<=2000){$methods[$service_postefrancaise]['charge']=17.35;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>2000 && $params['Weight']<=3000){$methods[$service_postefrancaise]['charge']=22.00;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>3000 && $params['Weight']<=4000){$methods[$service_postefrancaise]['charge']=26.65;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>4000 && $params['Weight']<=5000){$methods[$service_postefrancaise]['charge']=31.30;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>5000 && $params['Weight']<=6000){$methods[$service_postefrancaise]['charge']=35.95;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>6000 && $params['Weight']<=7000){$methods[$service_postefrancaise]['charge']=40.60;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>7000 && $params['Weight']<=8000){$methods[$service_postefrancaise]['charge']=45.25;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>8000 && $params['Weight']<=9000){$methods[$service_postefrancaise]['charge']=49.90;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>9000 && $params['Weight']<=10000){$methods[$service_postefrancaise]['charge']=54.55;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>10000 && $params['Weight']<=15000){$methods[$service_postefrancaise]['charge']=77.75;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>15000 && $params['Weight']<=20000){$methods[$service_postefrancaise]['charge']=100.95;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>20000 && $params['Weight']<=25000){$methods[$service_postefrancaise]['charge']=124.15;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>25000 && $params['Weight']<=30000){$methods[$service_postefrancaise]['charge']=147.35;$methods[$service_postefrancaise]['err_msg']='OK';}
			else {$methods[$service_postefrancaise]['err_msg']='Poids non trouvé';}
		}
		elseif ( 
		$params['Country']=='AD' || 
    $params['Country']=='AL' ||
    $params['Country']=='AM' ||
    $params['Country']=='AT' ||
    $params['Country']=='AX' ||
    $params['Country']=='AZ' ||
    $params['Country']=='BA' ||
    $params['Country']=='BE' ||
    $params['Country']=='BG' ||
    $params['Country']=='BY' ||
    $params['Country']=='CH' ||
    $params['Country']=='CY' ||
    $params['Country']=='CZ' ||
    $params['Country']=='DE' ||
    $params['Country']=='DK' ||
    $params['Country']=='EE' ||
    $params['Country']=='ES' ||
    $params['Country']=='FI' ||
    $params['Country']=='FO' ||
    $params['Country']=='FR' ||
    $params['Country']=='GB' ||
    $params['Country']=='GE' ||
    $params['Country']=='GG' ||
    $params['Country']=='GI' ||
    $params['Country']=='GR' ||
    $params['Country']=='HR' ||
    $params['Country']=='HU' ||
    $params['Country']=='IE' ||
    $params['Country']=='IM' ||
    $params['Country']=='IS' ||
    $params['Country']=='IT' ||
    $params['Country']=='JE' ||
    $params['Country']=='KZ' ||
    $params['Country']=='LI' ||
    $params['Country']=='LT' ||
    $params['Country']=='LU' ||
    $params['Country']=='LV' ||
    $params['Country']=='MC' ||
    $params['Country']=='MD' ||
    $params['Country']=='ME' ||
    $params['Country']=='MK' ||
    $params['Country']=='MT' ||
    $params['Country']=='NL' ||
    $params['Country']=='NO' ||
    $params['Country']=='PL' ||
    $params['Country']=='PT' ||
    $params['Country']=='RO' ||
    $params['Country']=='RS' ||
    $params['Country']=='RU' ||
    $params['Country']=='SE' ||
    $params['Country']=='SI' ||
    $params['Country']=='SJ' ||
    $params['Country']=='SK' ||
    $params['Country']=='SM' ||
    $params['Country']=='TR' ||
    $params['Country']=='UA' ||
    $params['Country']=='VA' ){
			$methods[$service_postefrancaise]['name']='Colissimo International Zone A';
			$methods[$service_postefrancaise]['days']=''; // Temps de livraison standard Zone OM1 // todo : faire une option
		// Zone Internationale A
			if($params['Weight']>=0 && $params['Weight']<=1000){$methods[$service_postefrancaise]['charge']=16.15;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>1000 && $params['Weight']<=2000){$methods[$service_postefrancaise]['charge']=17.85;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>2000 && $params['Weight']<=3000){$methods[$service_postefrancaise]['charge']=21.55;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>3000 && $params['Weight']<=4000){$methods[$service_postefrancaise]['charge']=25.25;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>4000 && $params['Weight']<=5000){$methods[$service_postefrancaise]['charge']=28.95;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>5000 && $params['Weight']<=6000){$methods[$service_postefrancaise]['charge']=32.65;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>6000 && $params['Weight']<=7000){$methods[$service_postefrancaise]['charge']=36.35;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>7000 && $params['Weight']<=8000){$methods[$service_postefrancaise]['charge']=40.05;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>8000 && $params['Weight']<=9000){$methods[$service_postefrancaise]['charge']=43.75;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>9000 && $params['Weight']<=10000){$methods[$service_postefrancaise]['charge']=47.45;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>10000 && $params['Weight']<=15000){$methods[$service_postefrancaise]['charge']=54.65;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>15000 && $params['Weight']<=20000){$methods[$service_postefrancaise]['charge']=61.85;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>20000 && $params['Weight']<=25000){$methods[$service_postefrancaise]['charge']=69.05;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>25000 && $params['Weight']<=30000){$methods[$service_postefrancaise]['charge']=76.25;$methods[$service_postefrancaise]['err_msg']='OK';}
			else {$methods[$service_postefrancaise]['err_msg']='Poids non trouvé';}
		}
		elseif ($params['Country']=='DZ' || $params['Country']=='MA' || $params['Country']=='LY' || $params['Country']=='TN' || $params['Country']=='MR'
		// + Europe de l'est todo.
		){
			$methods[$service_postefrancaise]['name']='Colissimo International Zone B';
			$methods[$service_postefrancaise]['days']=''; // Temps de livraison standard Zone B // todo : faire une option
		// Zone Internationale B
			if($params['Weight']>=0 && $params['Weight']<=1000){$methods[$service_postefrancaise]['charge']=19.80;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>1000 && $params['Weight']<=2000){$methods[$service_postefrancaise]['charge']=21.70;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>2000 && $params['Weight']<=3000){$methods[$service_postefrancaise]['charge']=26.25;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>3000 && $params['Weight']<=4000){$methods[$service_postefrancaise]['charge']=30.80;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>4000 && $params['Weight']<=5000){$methods[$service_postefrancaise]['charge']=35.35;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>5000 && $params['Weight']<=6000){$methods[$service_postefrancaise]['charge']=39.90;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>6000 && $params['Weight']<=7000){$methods[$service_postefrancaise]['charge']=44.45;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>7000 && $params['Weight']<=8000){$methods[$service_postefrancaise]['charge']=49.00;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>8000 && $params['Weight']<=9000){$methods[$service_postefrancaise]['charge']=53.55;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>9000 && $params['Weight']<=10000){$methods[$service_postefrancaise]['charge']=58.10;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>10000 && $params['Weight']<=15000){$methods[$service_postefrancaise]['charge']=68.50;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>15000 && $params['Weight']<=20000){$methods[$service_postefrancaise]['charge']=78.90;$methods[$service_postefrancaise]['err_msg']='OK';}
			else {$methods[$service_postefrancaise]['err_msg']='Poids non trouvé';}
		
		
		}
		elseif ($params['Country']=='CA' || $params['Country']=='US' 
		// + Proche et moyen Orient todo
		// + Afrique Hors Magreb todo
		){
			$methods[$service_postefrancaise]['name']='Colissimo International Zone C';
			$methods[$service_postefrancaise]['days']=''; // Temps de livraison standard Zone C // todo : faire une option
		// Zone Internationale C
			if($params['Weight']>=0 && $params['Weight']<=1000){$methods[$service_postefrancaise]['charge']=23.20;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>1000 && $params['Weight']<=2000){$methods[$service_postefrancaise]['charge']=31.10;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>2000 && $params['Weight']<=3000){$methods[$service_postefrancaise]['charge']=40.90;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>3000 && $params['Weight']<=4000){$methods[$service_postefrancaise]['charge']=50.70;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>4000 && $params['Weight']<=5000){$methods[$service_postefrancaise]['charge']=60.50;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>5000 && $params['Weight']<=6000){$methods[$service_postefrancaise]['charge']=70.30;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>6000 && $params['Weight']<=7000){$methods[$service_postefrancaise]['charge']=80.10;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>7000 && $params['Weight']<=8000){$methods[$service_postefrancaise]['charge']=89.90;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>8000 && $params['Weight']<=9000){$methods[$service_postefrancaise]['charge']=99.70;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>9000 && $params['Weight']<=10000){$methods[$service_postefrancaise]['charge']=109.50;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>10000 && $params['Weight']<=15000){$methods[$service_postefrancaise]['charge']=133.60;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>15000 && $params['Weight']<=20000){$methods[$service_postefrancaise]['charge']=157.70;$methods[$service_postefrancaise]['err_msg']='OK';}
			else {$methods[$service_postefrancaise]['err_msg']='Poids non trouvé';}
		
		
		}
		
		else { // Tarif internationaux Colissimo Zone D
			$methods[$service_postefrancaise]['days']='';
			$methods[$service_postefrancaise]['name']='Colissimo International Zone D';
			if($params['Weight']>=0 && $params['Weight']<=1000){$methods[$service_postefrancaise]['charge']=26.40;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>1000 && $params['Weight']<=2000){$methods[$service_postefrancaise]['charge']=39.70;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>2000 && $params['Weight']<=3000){$methods[$service_postefrancaise]['charge']=52.90;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>3000 && $params['Weight']<=4000){$methods[$service_postefrancaise]['charge']=66.10;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>4000 && $params['Weight']<=5000){$methods[$service_postefrancaise]['charge']=79.30;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>5000 && $params['Weight']<=6000){$methods[$service_postefrancaise]['charge']=92.50;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>6000 && $params['Weight']<=7000){$methods[$service_postefrancaise]['charge']=105.70;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>7000 && $params['Weight']<=8000){$methods[$service_postefrancaise]['charge']=118.90;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>8000 && $params['Weight']<=9000){$methods[$service_postefrancaise]['charge']=132.10;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>9000 && $params['Weight']<=10000){$methods[$service_postefrancaise]['charge']=145.30;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>10000 && $params['Weight']<=15000){$methods[$service_postefrancaise]['charge']=171.30;$methods[$service_postefrancaise]['err_msg']='OK';}
			elseif ($params['Weight']>15000 && $params['Weight']<=20000){$methods[$service_postefrancaise]['charge']=197.30;$methods[$service_postefrancaise]['err_msg']='OK';}
			else {$methods[$service_postefrancaise]['err_msg']='Poids non trouvé';}
		
		}
		
		// CHRONOPOST (Seulement vers la France et Monaco)
		$service_postefrancaise='CHRONOPOST';
		if ($params['Country']=='FR'){
		$methods[$service_postefrancaise]['name']='Chrono 13';
		$methods[$service_postefrancaise]['days']=2;
		if($params['Weight']>=0 && $params['Weight']<=500){$methods[$service_postefrancaise]['charge']=22.50;$methods[$service_postefrancaise]['err_msg']='OK';}
		elseif ($params['Weight']>500 && $params['Weight']<=1000){$methods[$service_postefrancaise]['charge']=23.00;$methods[$service_postefrancaise]['err_msg']='OK';}
		elseif ($params['Weight']>1000 && $params['Weight']<=2000){$methods[$service_postefrancaise]['charge']=25.00;$methods[$service_postefrancaise]['err_msg']='OK';}
		else {$methods[$service_postefrancaise]['err_msg']='Poids non trouvé';}
		}

	
		$service_postefrancaise='ENLEVEMENT';
		$methods[$service_postefrancaise]['name']='Enlèvement sur place';
		$methods[$service_postefrancaise]['charge']=0;
		$methods[$service_postefrancaise]['err_msg']='OK';
		
		// Allow another WordPress plugin to override the quoted method(s)/amount(s)
		$methods = apply_filters('wpsc_postefrancaise_methods', $methods, $this->base_zipcode, $destzipcode, $dest, $weight);
		
		$quotedMethods = array();
		
		// Debug Thomas :
		//$text = sprintf('Poids : %1$d grammes',$params['Weight']);
		//$quotedMethods[$text] = 1;
		
		
		foreach ($methods as $code => $data) {
			// Only include methods with an OK response
			if ($data['err_msg'] != 'OK') continue;
			if ($methods[$service_postefrancaise]['name']=='Enlèvement sur place') {
				$text = $data['name'].' '.$this->address;
				}
			else {
				if ($data['days']) {
					// If the estimated number of days is specified, so include it in the quote
					$text = sprintf('%1$s (temps de livraison estimé : %2$d jours ouvrables)', $data['name'], $data['days']);
					}
				else {
					// No time estimate
					$text = $data['name'];
					}
				}
			$quotedMethods[$text] = $data['charge'];
		}
		return $quotedMethods;
	}
	
	function get_item_shipping() {}
}

function postefrancaise_setup() {
	global $wpsc_shipping_modules;
	$postefrancaise = new postefrancaise();
	$wpsc_shipping_modules[$postefrancaise->getInternalName()] = $postefrancaise;
}

add_action('plugins_loaded', 'postefrancaise_setup');

?>